@@ -92,8 +92,16 @@ _set_mac_address()
 
 _get_inet_addresses()
 {
-	LC_ALL=C ip -family inet addr show "${IFACE}" | \
-	sed -n -e 's/.*inet \([^ ]*\).*/\1/p'
+	local family="$1";
+	if [ -z "$family" ]; then
+		family="inet"
+	fi
+	LC_ALL=C ip -family $family addr show "${IFACE}" | \
+	sed -n -e 's/.*inet6\? \([^ ]*\).*/\1/p'
+}
+
+_get_inet6_addresses() {
+	_get_inet_addresses "inet6"
 }
 
 _get_inet_address()
@@ -103,6 +111,13 @@ _get_inet_address()
 	echo "$1"
 }
 
+_get_inet6_address()
+{
+	set -- $(_get_inet6_addresses)
+	[ $# = "0" ] && return 1
+	echo "$1"
+}
+
 _add_address()
 {
 	if [ "$1" = "127.0.0.1/8" -a "${IFACE}" = "lo" ]; then
@@ -438,8 +453,18 @@ _iproute2_link_delete() {
 	eend $?
 }
 
+_iproute2_route_flush_supported() {
+	case $FAMILY in
+		-6) p='/proc/sys/net/ipv6/route/flush' ;;
+		-4|*) p='/proc/sys/net/ipv4/route/flush' ;;
+	esac
+	test -f $p
+}
+
 _iproute2_route_flush() {
-	_cmd ip $FAMILY route flush table cache dev "${IFACE}"
+	if _iproute2_route_flush_supported; then
+		_cmd ip $FAMILY route flush table cache dev "${IFACE}"
+	fi
 }
 
 _iproute2_ipv6_tentative_output() {
