@@ -5,6 +5,7 @@
 
 _config_vars="$_config_vars ssid mode associate_timeout sleep_scan"
 _config_vars="$_config_vars preferred_aps blacklist_aps"
+_config_vars="$_config_vars mesh"
 
 iw_depend()
 {
@@ -170,6 +171,26 @@ iw_setup_adhoc()
 	return 0
 }
 
+iw_setup_mesh()
+{
+	if [ -z "${MESH}" ]; then
+		eerror "${IFACE} requires a MESH to be set to operate in mesh mode"
+		eerror "adjust the mesh_${IFVAR} setting in /etc/conf.d/net"
+		return 1
+	fi
+
+	iw_set_mode 'mesh'
+
+	veinfo "Joining mesh '$MESH' with $IFACE"
+	iw ${IFACE} mesh join "${MESH}" || return 1
+
+	# Finally apply the user Config
+	iw_user_config
+
+	iw_report
+	return 0
+}
+
 iw_wait_for_association()
 {
 	local timeout= i=0
@@ -585,27 +606,34 @@ iw_configure()
 	[ -z "${SSID}" ] && eval SSID=\$essid_${IFVAR}
 
 	# Setup ad-hoc mode?
-	eval x=\$mode_${IFVAR}
-	x=${x:-managed}
+	eval _mode=\$mode_${IFVAR}
+	_mode=${_mode:-managed}
 
-	if [ "${x}" = "master" ]; then
-		eerror "Please use hostapd to make this interface an access point"
-		return 1
-	fi
-
-	if [ "${x}" = "ad-hoc" ]; then
-		iw_setup_adhoc
-		return $?
-	fi
-
-	if [ "${x}" != "managed" ]; then
-		eerror "Only managed and ad-hoc are supported"
-		return 1
-	fi
+	case "${_mode}" in
+		master)
+			eerror "Please use hostapd to make this interface an access point"
+			return 1
+			;;
+		ad-hoc|adhoc)
+			iw_setup_adhoc
+			return $?
+			;;
+		managed)
+			# Fall through
+			;;
+		mesh)
+			iw_setup_mesh
+			return $?
+			;;
+		*)
+			eerror "Only managed and ad-hoc are supported"
+			return 1
+			;;
+	esac
 
 	# Has an SSID been forced?
 	if [ -n "${SSID}" ]; then
-		iw_set_mode "${x}"
+		iw_set_mode "${_mode}"
 		iw_associate && return 0
 		[ "${SSID}" = "any" ] && iw_force_preferred && return 0
 
